@@ -1024,9 +1024,9 @@ void LALInferenceAdaptation(LALInferenceThreadState *thread) {
     INT4 adaptTau = LALInferenceGetINT4Variable(thread->proposalArgs, "adaptTau");
     INT4 length = LALInferenceGetINT4Variable(thread->proposalArgs, "adaptLength");
     INT4 adaptRestartBuffer = LALInferenceGetINT4Variable(thread->proposalArgs, "adaptResetBuffer");
-    REAL8 logLAtAdaptStart = LALInferenceGetREAL8Variable(thread->proposalArgs, "logLAtAdaptStart");
+    REAL8 logPAtAdaptStart = LALInferenceGetREAL8Variable(thread->proposalArgs, "logPAtAdaptStart");
 
-    if (thread->currentLikelihood > logLAtAdaptStart+(REAL8)nPar/2) {
+    if (thread->currentPrior + thread->currentLikelihood > logPAtAdaptStart+(REAL8)nPar/2) {
         LALInferenceAdaptationRestart(thread);
     } else if (adapting) {
         /* Turn off adaption after adaptLength steps without restarting */
@@ -1070,6 +1070,8 @@ void LALInferenceAdaptationRestart(LALInferenceThreadState *thread) {
         }
     }
 
+    REAL8 current_posterior = thread->currentPrior + thread->currentLikelihood;
+
     INT4 length = LALInferenceGetINT4Variable(thread->proposalArgs, "adaptLength");
     INT4 tau = LALInferenceGetINT4Variable(thread->proposalArgs, "adaptTau");
     INT4 adaptRestartBuffer = LALInferenceGetINT4Variable(thread->proposalArgs, "adaptResetBuffer");
@@ -1077,7 +1079,7 @@ void LALInferenceAdaptationRestart(LALInferenceThreadState *thread) {
     LALInferenceAddVariable(thread->proposalArgs, "s_gamma", &s_gamma, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_OUTPUT);
 
     LALInferenceSetVariable(thread->proposalArgs, "adapting", &adapting);
-    LALInferenceSetVariable(thread->proposalArgs, "logLAtAdaptStart", &(thread->currentLikelihood));
+    LALInferenceSetVariable(thread->proposalArgs, "logPAtAdaptStart", &(current_posterior));
     LALInferenceSetVariable(thread->proposalArgs, "acl", &bigACL);
 
     thread->step = -length;
@@ -1151,9 +1153,9 @@ void LALInferenceNameOutputs(LALInferenceRunState *runState) {
     }
 
     if((ppt=LALInferenceGetProcParamVal(runState->commandLine, "--runid")))
-        snprintf(runState->runID, 255, "%s_%s", "lalinference_mcmc",ppt->value);
+        snprintf(runState->runID, sizeof(runState->runID), "%s_%s", "lalinference_mcmc",ppt->value);
     else
-        snprintf(runState->runID, 255, "lalinference_mcmc");
+        snprintf(runState->runID, sizeof(runState->runID), "lalinference_mcmc");
 }
 
 
@@ -1216,7 +1218,7 @@ void LALInferenceCheckpointMCMC(LALInferenceRunState *runState) {
         LALInferenceH5VariablesArrayToDataset(chain_group, &(thread->currentParams), 1, "current_parameters");
         XLALH5FileAddScalarAttribute(chain_group, "temperature", &(thread->temperature), LAL_D_TYPE_CODE);
         XLALH5FileAddScalarAttribute(chain_group, "last_step", &(thread->step), LAL_I4_TYPE_CODE);
-        XLALH5FileAddScalarAttribute(chain_group, "effective_sample_size", &(thread->effective_sample_size), LAL_D_TYPE_CODE);
+        XLALH5FileAddScalarAttribute(chain_group, "effective_sample_size", &(thread->effective_sample_size), LAL_I4_TYPE_CODE);
         XLALH5FileAddScalarAttribute(chain_group, "differential_point_skip", &(thread->differentialPointsSkip), LAL_I4_TYPE_CODE);
 
         /* Store the total number of temperature swaps accepted over the stored window */
@@ -1456,7 +1458,7 @@ void LALInferencePrintPTMCMCHeaderFile(LALInferenceRunState *runState, LALInfere
         benchmark = 1;
 
     /* Print version info */
-    fprintf(threadoutput, "  LALInference version:%s,%s,%s,%s,%s\n", lalAppsVCSId,lalAppsVCSDate,lalAppsVCSBranch,lalAppsVCSAuthor,lalAppsVCSStatus);
+    fprintf(threadoutput, "  LALInference version:%s,%s,%s,%s,%s\n", lalAppsVCSInfo.vcsId, lalAppsVCSInfo.vcsDate, lalAppsVCSInfo.vcsBranch, lalAppsVCSInfo.vcsAuthor, lalAppsVCSInfo.vcsStatus);
     fprintf(threadoutput,"  %s\n", arg_str);
 
     /* Print algorithm parameters */
