@@ -1,5 +1,6 @@
 /*
- * LALAppsVCSInfo.h - LALApps VCS Information Header
+ * Copyright (C) 2014, 2016 Karl Wette
+ * Copyright (C) 2009-2013 Adam Mercer
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +16,10 @@
  * along with with program; see the file COPYING. If not, write to the
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA 02111-1307 USA
- *
- * Copyright (C) 2009-2013 Adam Mercer
- * Copyright (C) 2014 Karl Wette
+ */
+
+/*
+ * LALAppsVCSInfo.h - LALApps VCS Information Header
  */
 
 /** \cond DONT_DOXYGEN */
@@ -33,37 +35,19 @@
 extern "C" {
 #endif
 
-/* VCS information defines */
-#define LALAPPS_NAME "LALApps"
-#define LALAPPS_VCS_ID "6c73f0c9d565841e343bedb55f412531b52ec2ac"
-#define LALAPPS_VCS_DATE "2016-10-10 17:31:35 +0000"
+/* VCS information */
+#define LALAPPS_VCS_ID "ba160287551f30ebb687ad38cebd5b50b05ec3cc"
+#define LALAPPS_VCS_DATE "2017-02-6 18:17:18 +0000"
 #define LALAPPS_VCS_BRANCH "None"
-#define LALAPPS_VCS_TAG "lalapps-v6.20.0"
+#define LALAPPS_VCS_TAG "lalapps-v6.21.0"
 #define LALAPPS_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
 #define LALAPPS_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
+#define LALAPPS_VCS_CLEAN "CLEAN"
 #define LALAPPS_VCS_STATUS "CLEAN: All modifications committed"
 
-/* Identable VCS information defines */
-#define LALAPPS_VCS_IDENT_ID "$" "LALAppsId: 6c73f0c9d565841e343bedb55f412531b52ec2ac " "$"
-#define LALAPPS_VCS_IDENT_DATE "$" "LALAppsDate: 2016-10-10 17:31:35 +0000 " "$"
-#define LALAPPS_VCS_IDENT_BRANCH "$" "LALAppsBranch: None " "$"
-#define LALAPPS_VCS_IDENT_TAG "$" "LALAppsTag: lalapps-v6.20.0 " "$"
-#define LALAPPS_VCS_IDENT_AUTHOR "$" "LALAppsAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALAPPS_VCS_IDENT_COMMITTER "$" "LALAppsCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALAPPS_VCS_IDENT_STATUS "$" "LALAppsStatus: CLEAN: All modifications committed " "$"
-
-/* Header VCS information structure */
-static const LALVCSInfo lalAppsVCSInfoHeader = { \
-  LALAPPS_NAME, \
-  LALAPPS_VERSION, \
-  LALAPPS_VCS_ID, \
-  LALAPPS_VCS_DATE, \
-  LALAPPS_VCS_BRANCH, \
-  LALAPPS_VCS_TAG, \
-  LALAPPS_VCS_AUTHOR, \
-  LALAPPS_VCS_COMMITTER, \
-  LALAPPS_VCS_STATUS \
-};
+/* VCS header/library mismatch link check function */
+#define LALAPPS_VCS_LINK_CHECK LALAPPS_CLEAN_ba160287551f30ebb687ad38cebd5b50b05ec3cc_VCS_HEADER_LIBRARY_MISMATCH
+void LALAPPS_VCS_LINK_CHECK(void);
 
 #ifdef __cplusplus
 }
@@ -72,7 +56,3 @@ static const LALVCSInfo lalAppsVCSInfoHeader = { \
 #endif /* _LALAPPSVCSINFOHEADER_H */
 
 /** \endcond */
-
-/*
- * vim: tw=0 ts=2 et
- */
