@@ -135,7 +135,7 @@ INT4 test=0;
 
 UINT4 ARRAY_SIZE=0;
 
-/* function to convert a GPS time in JD to TDB (similar to my routine LALTDBMJDtoGPS) */
+/* function to convert a GPS time in JD to TDB (similar to my routine XLALTDBMJDtoGPS) */
 void convert(REAL8 *gps_JD, REAL8 *time);
 
 /* function to read the record length of the binary file - this differs for
@@ -328,9 +328,9 @@ writing!\n");
 
     /* output header information on lines starting with a # comment */
     fprintf(fpe, "# Build information for %s\n", argv[0]);
-    fprintf(fpe, "# Author: %s\n", lalAppsVCSAuthor);
-    fprintf(fpe, "# LALApps Commit ID: %s\n", lalAppsVCSId);
-    fprintf(fpe, "# LALApps Commit Date: %s\n", lalAppsVCSDate);
+    fprintf(fpe, "# Author: %s\n", lalAppsVCSInfo.vcsAuthor);
+    fprintf(fpe, "# LALApps Commit ID: %s\n", lalAppsVCSInfo.vcsId);
+    fprintf(fpe, "# LALApps Commit Date: %s\n", lalAppsVCSInfo.vcsDate);
     fprintf(fpe, "#\n# Ephemeris creation command:-\n#\t");
     for( INT4 k=0; k<argc; k++ ) fprintf(fpe, "%s ", argv[k]);
     fprintf(fpe, "\n");
