@@ -123,6 +123,8 @@ void ComputeF(LALStatus *, struct CommandLineArgsTag CLA);
 
 void CheckUserInput (LALStatus *,  struct CommandLineArgsTag *CLA );
 
+static void LALComputeAM (LALStatus *, AMCoeffs *coe, LIGOTimeGPS *ts, AMCoeffsParams *params);
+
 /*---------- function definitions ---------- */
 int main(int argc,char *argv[]) 
 {
@@ -138,7 +140,7 @@ int main(int argc,char *argv[])
 
   /* read cmdline & cfgfile  */	
   BOOLEAN should_exit = 0;
-  LAL_CALL (LALUserVarReadAllInput(&status, &should_exit, argc, argv), &status);
+  XLAL_CHECK_MAIN (XLALUserVarReadAllInput(&should_exit, argc, argv) == XLAL_SUCCESS, XLAL_EFUNC);
   if (should_exit)
     return EXIT_FAILURE;
   LAL_CALL ( CheckUserInput (&status, &CommandLineArgs), &status);
@@ -152,7 +154,7 @@ int main(int argc,char *argv[])
   /* Free remaining memory */
   LAL_CALL ( LALSDestroyVector(&status, &(amc.a) ), &status);
   LAL_CALL ( LALSDestroyVector(&status, &(amc.b) ), &status);
-  LAL_CALL ( LALDestroyUserVars(&status), &status);
+  XLALDestroyUserVars();
 
   LALCheckMemoryLeaks();
 
@@ -227,74 +229,42 @@ InitUserVars (LALStatus *status, struct CommandLineArgsTag *CLA)
   CLA->ephemSun = XLALStringDuplicate("sun00-19-DE405.dat.gz");
   
   /* ---------- register all our user-variable ---------- */
-  TRY( LALRegisterREALUserVar(status->statusPtr, "Alpha", 'a', UVAR_OPTIONAL, 
-			      "Sky position Alpha (equatorial coordinates) in radians", 
-			      &(CLA->Alpha)), status);
-  TRY( LALRegisterREALUserVar(status->statusPtr, "longitude",  0, UVAR_DEVELOPER, 
-			      "[DEPRECATED] Use --Alpha instead!",  
-			      &(CLA->Alpha)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->Alpha),      "Alpha",          REAL8,  'a', OPTIONAL,  "Sky position Alpha (equatorial coordinates) in radians") == XLAL_SUCCESS, XLAL_EFUNC);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->Alpha),      "longitude",      REAL8,  0,   DEVELOPER, "[DEPRECATED] Use --Alpha instead!") == XLAL_SUCCESS, XLAL_EFUNC);
 
-  TRY( LALRegisterREALUserVar(status->statusPtr, "Delta", 'd', UVAR_OPTIONAL, 
-			      "Sky position Delta (equatorial coordinates) in radians", 
-			      &(CLA->Delta)), status);
-  TRY( LALRegisterREALUserVar(status->statusPtr, "latitude", 0, UVAR_DEVELOPER, 
-			      "[DEPRECATED] Use --Delta instead!", 
-			      &(CLA->Delta)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->Delta),      "Delta",          REAL8,  'd', OPTIONAL,  "Sky position Delta (equatorial coordinates) in radians") == XLAL_SUCCESS, XLAL_EFUNC);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->Delta),      "latitude",       REAL8,  0,   DEVELOPER, "[DEPRECATED] Use --Delta instead!") == XLAL_SUCCESS, XLAL_EFUNC);
  
-  TRY( LALRegisterREALUserVar(status->statusPtr, "phi0",   'Q', UVAR_OPTIONAL, 
-			     "Phi_0: Initial phase in radians", &(CLA->phi0)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->phi0),       "phi0",           REAL8,  'Q', OPTIONAL,  "Phi_0: Initial phase in radians") == XLAL_SUCCESS, XLAL_EFUNC);
 
-  TRY( LALRegisterREALUserVar(status->statusPtr, "psi",    'Y', UVAR_OPTIONAL, 
-			     "Polarisation in radians", &(CLA->psi)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->psi),        "psi",            REAL8,  'Y', OPTIONAL,  "Polarisation in radians") == XLAL_SUCCESS, XLAL_EFUNC);
 
-  TRY( LALRegisterREALUserVar(status->statusPtr, "cosi",   'i', UVAR_OPTIONAL, 
-			      "Cos(iota)", &(CLA->cosi)), status);
-  TRY( LALRegisterREALUserVar(status->statusPtr, "cosiota", 0, UVAR_DEVELOPER, 
-			      "[DEPRECATED] Use --cosi instead", &(CLA->cosiota)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->cosi),       "cosi",           REAL8,  'i', OPTIONAL,  "Cos(iota)") == XLAL_SUCCESS, XLAL_EFUNC);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->cosiota),    "cosiota",        REAL8,  0,   DEVELOPER, "[DEPRECATED] Use --cosi instead") == XLAL_SUCCESS, XLAL_EFUNC);
 
-  TRY( LALRegisterREALUserVar(status->statusPtr, "h0", 's', UVAR_OPTIONAL, 
-			      "Strain amplitude h_0", &(CLA->h0)), status);
-  TRY( LALRegisterREALUserVar(status->statusPtr, "sqrtSh", 'N', UVAR_OPTIONAL, 
-			      "Noise floor: one-sided sqrt(Sh) in 1/sqrt(Hz)", &(CLA->sqrtSh)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->h0),         "h0",             REAL8,  's', OPTIONAL,  "Strain amplitude h_0") == XLAL_SUCCESS, XLAL_EFUNC);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->sqrtSh),     "sqrtSh",         REAL8,  'N', OPTIONAL,  "Noise floor: one-sided sqrt(Sh) in 1/sqrt(Hz)") == XLAL_SUCCESS, XLAL_EFUNC);
   
-  TRY( LALRegisterSTRINGUserVar(status->statusPtr, "timestampsFile", 'T', UVAR_OPTIONAL, 
-				"Name of timestamps file", &(CLA->timestamps)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->timestamps), "timestampsFile", STRING, 'T', OPTIONAL,  "Name of timestamps file") == XLAL_SUCCESS, XLAL_EFUNC);
   
-  TRY( LALRegisterINTUserVar(status->statusPtr, "startTime", 'S', UVAR_OPTIONAL, 
-			     "GPS start time of continuous observation", &(CLA->gpsStart)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->gpsStart),   "startTime",      INT4,   'S', OPTIONAL,  "GPS start time of continuous observation") == XLAL_SUCCESS, XLAL_EFUNC);
   
-  TRY( LALRegisterREALUserVar(status->statusPtr, "Tsft", 't', UVAR_OPTIONAL, 
-			      "Length of an SFT in seconds", &(CLA->Tsft)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->Tsft),       "Tsft",           REAL8,  't', OPTIONAL,  "Length of an SFT in seconds") == XLAL_SUCCESS, XLAL_EFUNC);
   
-  TRY( LALRegisterINTUserVar(status->statusPtr, "nTsft", 'n', UVAR_OPTIONAL, 
-			     "Number of SFTs", &(CLA->nTsft)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->nTsft),      "nTsft",          INT4,   'n', OPTIONAL,  "Number of SFTs") == XLAL_SUCCESS, XLAL_EFUNC);
   
-  TRY( LALRegisterSTRINGUserVar(status->statusPtr, "IFO", 'D', UVAR_OPTIONAL, 
-				"Detector: H1, H2, L1, G1, ... ",
-				&(CLA->IFO)), status);
-  TRY( LALRegisterSTRINGUserVar(status->statusPtr, "detector",  0, UVAR_DEVELOPER, 
-				"[DEPRECATED] Use --IFO instead!",
-				&(CLA->detector)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->IFO),        "IFO",            STRING, 'D', OPTIONAL,  "Detector: H1, H2, L1, G1, ... ") == XLAL_SUCCESS, XLAL_EFUNC);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->detector),   "detector",       STRING, 0,   DEVELOPER, "[DEPRECATED] Use --IFO instead!") == XLAL_SUCCESS, XLAL_EFUNC);
   
-  TRY( LALRegisterSTRINGUserVar(status->statusPtr, "ephemEarth", 0, UVAR_OPTIONAL, 
-				"Earth ephemeris file to use", 
-				&(CLA->ephemEarth)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->ephemEarth), "ephemEarth",     STRING, 0,   OPTIONAL,  "Earth ephemeris file to use") == XLAL_SUCCESS, XLAL_EFUNC);
 
-  TRY( LALRegisterSTRINGUserVar(status->statusPtr, "ephemSun", 0, UVAR_OPTIONAL, 
-				"Sun ephemeris file to use", 
-				&(CLA->ephemSun)), status);
+  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar(&(CLA->ephemSun),   "ephemSun",       STRING, 0,   OPTIONAL,  "Sun ephemeris file to use") == XLAL_SUCCESS, XLAL_EFUNC);
 
   /* ----- added for mfd_v4 compatibility ---------- */
-  TRY ( LALRegisterREALUserVar(status->statusPtr, "duration", 0, UVAR_OPTIONAL,
-			       "Duration of requested signal in seconds", 
-			       &(CLA->duration)), status); 
+  XLAL_CHECK_LAL ( status, XLALRegisterNamedUvar(&(CLA->duration),  "duration",       REAL8, 0,    OPTIONAL,  "Duration of requested signal in seconds") == XLAL_SUCCESS, XLAL_EFUNC);
   
-  TRY ( LALRegisterREALUserVar(status->statusPtr, "aPlus", 0, UVAR_OPTIONAL, 
-			       "Plus polarization amplitude aPlus", 
-			       &(CLA->aPlus)), status);
-  TRY ( LALRegisterREALUserVar(status->statusPtr, "aCross", 0, UVAR_OPTIONAL, 
-			       "Cross polarization amplitude aCross", 
-			       &(CLA->aCross)), status);
+  XLAL_CHECK_LAL ( status, XLALRegisterNamedUvar(&(CLA->aPlus),     "aPlus",          REAL8, 0,    OPTIONAL,  "Plus polarization amplitude aPlus") == XLAL_SUCCESS, XLAL_EFUNC);
+  XLAL_CHECK_LAL ( status, XLALRegisterNamedUvar(&(CLA->aCross),    "aCross",         REAL8, 0,    OPTIONAL,  "Cross polarization amplitude aCross") == XLAL_SUCCESS, XLAL_EFUNC);
 
 
   DETATCHSTATUSPTR (status);
@@ -319,13 +289,13 @@ Initialize (LALStatus *status, struct CommandLineArgsTag *CLA)
   INITSTATUS(status);
   ATTATCHSTATUSPTR (status);
 
-  if ( LALUserVarWasSet ( &(CLA->nTsft) ) )
+  if ( XLALUserVarWasSet ( &(CLA->nTsft) ) )
     CLA->duration = 1.0 * CLA->nTsft * CLA->Tsft;
 
   /* read or generate SFT timestamps */
-  if ( LALUserVarWasSet(&(CLA->timestamps)) ) 
+  if ( XLALUserVarWasSet(&(CLA->timestamps)) ) 
     { 
-      TRY ( LALReadTimestampsFile (status->statusPtr, &timestamps, CLA->timestamps ), status );
+      XLAL_CHECK_LAL ( status, ( timestamps = XLALReadTimestampsFile ( CLA->timestamps ) ) != NULL, XLAL_EFUNC );
       if ( (CLA->nTsft > 0) && ( (UINT4)CLA->nTsft < timestamps->length ) )	/* truncate if required */
 	timestamps->length = CLA->nTsft;
       
@@ -337,15 +307,15 @@ Initialize (LALStatus *status, struct CommandLineArgsTag *CLA)
       tStart.gpsSeconds = CLA->gpsStart;
       tStart.gpsNanoSeconds = 0;
 
-      TRY ( LALMakeTimestamps(status->statusPtr, &timestamps, tStart, CLA->duration, CLA->Tsft ), status );
+      XLAL_CHECK_LAL ( status, ( timestamps = XLALMakeTimestamps( tStart, CLA->duration, CLA->Tsft, 0 ) ) != NULL, XLAL_EFUNC );
       CLA->nTsft = timestamps->length;
 
     } /* no timestamps */
 
   /*---------- initialize detector ---------- */
   {
-    BOOLEAN have_IFO       = LALUserVarWasSet ( &CLA->IFO );
-    BOOLEAN have_detector  = LALUserVarWasSet ( &CLA->detector );
+    BOOLEAN have_IFO       = XLALUserVarWasSet ( &CLA->IFO );
+    BOOLEAN have_detector  = XLALUserVarWasSet ( &CLA->detector );
     CHAR *IFO;
 
     if ( !have_IFO  && !have_detector ) {
@@ -402,8 +372,7 @@ Initialize (LALStatus *status, struct CommandLineArgsTag *CLA)
   amParams->polAngle = amParams->das->pSource->orientation ; /* These two have to be the same!!!!!!!!!*/
   
   /* Allocate space for AMCoeffs */
-  amc.a = NULL;
-  amc.b = NULL;
+  XLAL_INIT_MEM(amc);
   TRY ( LALSCreateVector(status->statusPtr, &(amc.a), (UINT4)  CLA->nTsft), status);
   TRY ( LALSCreateVector(status->statusPtr, &(amc.b), (UINT4)  CLA->nTsft), status);
   
@@ -424,7 +393,7 @@ Initialize (LALStatus *status, struct CommandLineArgsTag *CLA)
   TRY ( LALComputeAM(status->statusPtr, &amc, midTS, amParams), status);
 
   /* Free memory */
-  TRY ( LALDestroyTimestampVector (status->statusPtr, &timestamps), status );
+  XLALDestroyTimestampVector ( timestamps);
 
   LALFree(midTS);
   LALFree(Detector);
@@ -449,10 +418,10 @@ CheckUserInput (LALStatus *status,  struct CommandLineArgsTag *CLA )
 {
 
   /* set a few abbreviations */
-  BOOLEAN have_timestamps= LALUserVarWasSet (&(CLA->timestamps));
-  BOOLEAN have_gpsStart = LALUserVarWasSet  (&(CLA->gpsStart));
-  BOOLEAN have_duration  = LALUserVarWasSet (&(CLA->duration));
-  BOOLEAN have_nTsft     = LALUserVarWasSet (&(CLA->nTsft));
+  BOOLEAN have_timestamps= XLALUserVarWasSet (&(CLA->timestamps));
+  BOOLEAN have_gpsStart = XLALUserVarWasSet  (&(CLA->gpsStart));
+  BOOLEAN have_duration  = XLALUserVarWasSet (&(CLA->duration));
+  BOOLEAN have_nTsft     = XLALUserVarWasSet (&(CLA->nTsft));
   
   INITSTATUS(status);
   
@@ -483,10 +452,10 @@ CheckUserInput (LALStatus *status,  struct CommandLineArgsTag *CLA )
 
   /* now one can either specify {h0, cosiota} OR {aPlus, aCross} */
   {
-    BOOLEAN have_h0 = LALUserVarWasSet (&(CLA->h0));
-    BOOLEAN have_cosi = LALUserVarWasSet (&(CLA->cosi));
-    BOOLEAN have_aPlus = LALUserVarWasSet (&(CLA->aPlus));
-    BOOLEAN have_aCross = LALUserVarWasSet (&(CLA->aCross));
+    BOOLEAN have_h0 = XLALUserVarWasSet (&(CLA->h0));
+    BOOLEAN have_cosi = XLALUserVarWasSet (&(CLA->cosi));
+    BOOLEAN have_aPlus = XLALUserVarWasSet (&(CLA->aPlus));
+    BOOLEAN have_aCross = XLALUserVarWasSet (&(CLA->aCross));
     
     if ( (have_h0 || have_cosi) && (have_aPlus || have_aCross) ) 
       {
@@ -521,3 +490,82 @@ CheckUserInput (LALStatus *status,  struct CommandLineArgsTag *CLA )
   RETURN (status);
 
 } /* CheckUserInput() */
+
+
+/**
+ * Original antenna-pattern function by S Berukoff
+ */
+void LALComputeAM (LALStatus          *status,
+		   AMCoeffs           *coe,
+		   LIGOTimeGPS        *ts,
+		   AMCoeffsParams     *params)
+{
+
+  REAL4 zeta;                  /* sine of angle between detector arms        */
+  INT4 i;                      /* temporary loop index                       */
+  LALDetAMResponse response;   /* output of LALComputeDetAMResponse          */
+
+  REAL4 sumA2=0.0;
+  REAL4 sumB2=0.0;
+  REAL4 sumAB=0.0;             /* variables to store scalar products         */
+  INT4 length=coe->a->length;  /* length of input time series                */
+
+  REAL4 cos2psi;
+  REAL4 sin2psi;               /* temp variables                             */
+
+  INITSTATUS(status);
+  ATTATCHSTATUSPTR(status);
+
+  /* Must put an ASSERT checking that ts vec and coe vec are same length */
+
+  /* Compute the angle between detector arms, then the reciprocal */
+  {
+    LALFrDetector det = params->das->pDetector->frDetector;
+    zeta = 1.0/(sin(det.xArmAzimuthRadians - det.yArmAzimuthRadians));
+    if(params->das->pDetector->type == LALDETECTORTYPE_CYLBAR) zeta=1.0;
+  }
+
+  cos2psi = cos(2.0 * params->polAngle);
+  sin2psi = sin(2.0 * params->polAngle);
+
+  /* Note the length is the same for the b vector */
+  for(i=0; i<length; ++i)
+    {
+      REAL4 *a = coe->a->data;
+      REAL4 *b = coe->b->data;
+
+      /* Compute F_plus, F_cross */
+      LALComputeDetAMResponse(status->statusPtr, &response, params->das, &ts[i]);
+
+      /*  Compute a, b from JKS eq 10,11
+       *  a = zeta * (F_plus*cos(2\psi)-F_cross*sin(2\psi))
+       *  b = zeta * (F_cross*cos(2\psi)+Fplus*sin(2\psi))
+       */
+      a[i] = zeta * (response.plus*cos2psi-response.cross*sin2psi);
+      b[i] = zeta * (response.cross*cos2psi+response.plus*sin2psi);
+
+      /* Compute scalar products */
+      sumA2 += SQ(a[i]);                       /*  A  */
+      sumB2 += SQ(b[i]);                       /*  B  */
+      sumAB += (a[i]) * (b[i]);                /*  C  */
+    }
+
+  {
+    /* Normalization factor */
+    REAL8 L = 2.0/(REAL8)length;
+
+    /* Assign output values and normalise */
+    coe->A = L*sumA2;
+    coe->B = L*sumB2;
+    coe->C = L*sumAB;
+    coe->D = ( coe->A * coe->B - SQ(coe->C) );
+    /* protection against case when AB=C^2 */
+    if(coe->D == 0) coe->D=1.0e-9;
+  }
+
+  /* Normal exit */
+
+  DETATCHSTATUSPTR(status);
+  RETURN(status);
+
+} /* LALComputeAM() */
