@@ -98,6 +98,8 @@ extern char *global_column_headings_stringp;
 static void reduce_gctFstat_toplist_precision(toplist_t *l);
 static int _atomic_write_gctFstat_toplist_to_file(toplist_t *l, const char *filename, UINT4*checksum, int write_done);
 static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buflen);
+static int print_single_detector_quantities_to_str(char *outstr, size_t outstrlen, const REAL4 *quantities, const UINT4 numDetectors);
+static int print_single_detector_intval_to_str( char *outstr, size_t outstrlen, const INT4 *quantities, const UINT4 numDetectors );
 static int write_gctFstat_toplist_item_to_fp(GCTtopOutputEntry fline, FILE*fp, UINT4*checksum);
 
 /* ordering function for sorting the list */
@@ -191,6 +193,44 @@ static int gctBSGL_smaller(const void*a, const void*b) {
   else
     return(gctFstat_result_order(a,b));
 }
+/* ordering function defining the toplist: SORT BY BSGLtL */
+static int gctBSGLtL_smaller(const void*a, const void*b) {
+#ifdef DEBUG_SORTING
+  if(debugfp)
+    fprintf(debugfp,"%20lf  %20lf\n%20lf  %20lf\n\n",
+	    ((const GCTtopOutputEntry*)a)->avTwoF,  ((const GCTtopOutputEntry*)b)->avTwoF,
+	    ((const GCTtopOutputEntry*)a)->log10BSGLtL, ((const GCTtopOutputEntry*)b)->log10BSGLtL);
+#endif
+  if      (((const GCTtopOutputEntry*)a)->log10BSGLtL < ((const GCTtopOutputEntry*)b)->log10BSGLtL)
+    return 1;
+  else if (((const GCTtopOutputEntry*)a)->log10BSGLtL > ((const GCTtopOutputEntry*)b)->log10BSGLtL)
+    return -1;
+  else if (((const GCTtopOutputEntry*)a)->avTwoF < ((const GCTtopOutputEntry*)b)->avTwoF)
+    return 1;
+  else if (((const GCTtopOutputEntry*)a)->avTwoF > ((const GCTtopOutputEntry*)b)->avTwoF)
+    return -1;
+  else
+    return(gctFstat_result_order(a,b));
+}
+/* ordering function defining the toplist: SORT BY BtSGLtL */
+static int gctBtSGLtL_smaller(const void*a, const void*b) {
+#ifdef DEBUG_SORTING
+  if(debugfp)
+    fprintf(debugfp,"%20lf  %20lf\n%20lf  %20lf\n\n",
+	    ((const GCTtopOutputEntry*)a)->avTwoF,  ((const GCTtopOutputEntry*)b)->avTwoF,
+	    ((const GCTtopOutputEntry*)a)->log10BtSGLtL, ((const GCTtopOutputEntry*)b)->log10BtSGLtL);
+#endif
+  if      (((const GCTtopOutputEntry*)a)->log10BtSGLtL < ((const GCTtopOutputEntry*)b)->log10BtSGLtL)
+    return 1;
+  else if (((const GCTtopOutputEntry*)a)->log10BtSGLtL > ((const GCTtopOutputEntry*)b)->log10BtSGLtL)
+    return -1;
+  else if (((const GCTtopOutputEntry*)a)->avTwoF < ((const GCTtopOutputEntry*)b)->avTwoF)
+    return 1;
+  else if (((const GCTtopOutputEntry*)a)->avTwoF > ((const GCTtopOutputEntry*)b)->avTwoF)
+    return -1;
+  else
+    return(gctFstat_result_order(a,b));
+}
 
 
 /* functions for qsort based on the above ordering functions */
@@ -209,12 +249,18 @@ int create_gctFstat_toplist(toplist_t**tl, UINT8 length, UINT4 whatToSortBy) {
     debugfp=fopen("debug_sort","w");
 #endif
 
-  if (whatToSortBy==1) {
+  if (whatToSortBy==SORTBY_NC) {
     return( create_toplist(tl, length, sizeof(GCTtopOutputEntry), gctNC_smaller) );
   }
-  else if (whatToSortBy==2) {
+  else if (whatToSortBy==SORTBY_BSGL) {
     return( create_toplist(tl, length, sizeof(GCTtopOutputEntry), gctBSGL_smaller) );
   }
+  else if (whatToSortBy==SORTBY_BSGLtL) {
+    return( create_toplist(tl, length, sizeof(GCTtopOutputEntry), gctBSGLtL_smaller) );
+  }
+  else if (whatToSortBy==SORTBY_BtSGLtL) {
+    return( create_toplist(tl, length, sizeof(GCTtopOutputEntry), gctBtSGLtL_smaller) );
+  }
   else {
     return( create_toplist(tl, length, sizeof(GCTtopOutputEntry), gctFstat_smaller) );
   }
@@ -233,11 +279,11 @@ void free_gctFstat_toplist(toplist_t**l) {
    In the latter case, remove the smallest element from the toplist and
    look for the now smallest one.
    Returns 1 if the element was actually inserted, 0 if not. */
-int insert_into_gctFstat_toplist(toplist_t*tl, GCTtopOutputEntry elem) {
+int insert_into_gctFstat_toplist(toplist_t*tl, GCTtopOutputEntry * elem) {
   if ( !tl )
     return 0;
   else
-    return(insert_into_toplist(tl, (void*)&elem));
+    return(insert_into_toplist(tl, (void*) elem));
 }
 
 /* (q)sort the toplist according to the sorting function. */
@@ -248,26 +294,34 @@ void sort_gctFstat_toplist(toplist_t*l) {
 /* Prints a Toplist line to a string buffer.
    Separate function to assure consistency of output and reduced precision for sorting */
 static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buflen) {
-  const char *fn = __func__;
 
   /* add extra output field for line-robust statistic BSGL */
   char BSGLstr[256] = "";	/* defaults to empty */
   if ( fline.log10BSGL > -LAL_REAL4_MAX*0.2 ) /* if --computeBSGL=FALSE, the log10BSGL field was initialised to -LAL_REAL4_MAX; if --computeBSGL=TRUE, it is at least -LAL_REAL4_MAX*0.1 */
     {
-      char buf0[256];
       snprintf ( BSGLstr, sizeof(BSGLstr), " %.6f", fline.log10BSGL );
-      for ( UINT4 X = 0; X < fline.numDetectors ; X ++ )
-        {
-          snprintf ( buf0, sizeof(buf0), " %.6f", fline.avTwoFX[X] );
-          UINT4 len1 = strlen ( BSGLstr ) + strlen ( buf0 ) + 1;
-          if ( len1 > sizeof ( BSGLstr ) ) {
-            XLALPrintError ("%s: assembled output string too long! (%d > %zu)\n", fn, len1, sizeof(BSGLstr ));
-            break;	/* we can't really terminate with error in this function, but at least we avoid crashing */
-          }
-          strcat ( BSGLstr, buf0 );
-        } /* for X < numDet */
-
+      print_single_detector_quantities_to_str ( BSGLstr, sizeof(BSGLstr), fline.avTwoFX, fline.numDetectors );
     } /* if fline.log10BSGL */
+
+  /* add extra output fields for line-robust statistic BSGLtL and BtSGLtL */
+  char BSGLtLstr[256] = "";	/* defaults to empty */
+  if ( fline.log10BSGLtL > -LAL_REAL4_MAX*0.2 ) {
+    snprintf ( BSGLtLstr, sizeof(BSGLtLstr), " %.6f", fline.log10BSGLtL );
+  }
+  char BtSGLtLstr[256] = "";	/* defaults to empty */
+  if ( fline.log10BtSGLtL > -LAL_REAL4_MAX*0.2 ) {
+    snprintf ( BtSGLtLstr, sizeof(BtSGLtLstr), " %.6f", fline.log10BtSGLtL );
+  }
+
+  /* add extra output fields for max2F over segments */
+  char maxTwoFstr[256] = "";	/* defaults to empty */
+  if ( fline.maxTwoFl >= 0.0 ) /* this was initialised to -1.0 and is only >= 0.0 if actually computed in inner loop */
+    {
+      snprintf ( maxTwoFstr, sizeof(maxTwoFstr), " %.6f %d", fline.maxTwoFl, fline.maxTwoFlSeg );
+      print_single_detector_quantities_to_str ( maxTwoFstr, sizeof(maxTwoFstr), fline.maxTwoFXl, fline.numDetectors );
+      print_single_detector_intval_to_str ( maxTwoFstr, sizeof(maxTwoFstr), fline.maxTwoFXlSeg, fline.numDetectors );
+    }
+
   /* add extra output fields for recalculated statistics */
   char recalcStr[256] = "";	/* defaults to empty */
   if ( fline.avTwoFrecalc >= 0.0 ) /* this was initialised to -1.0 and is only >= 0.0 if actually recomputed in recalcToplistStats step */
@@ -279,32 +333,22 @@ static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
           snprintf ( buf0, sizeof(buf0), " %.6f", fline.log10BSGLrecalc );
           strcat ( recalcStr, buf0 );
         } /* if ( fline.log10BSGL > -LAL_REAL4_MAX*0.2 ) */
-      for ( UINT4 X = 0; X < fline.numDetectors ; X ++ )
-        {
-          snprintf ( buf0, sizeof(buf0), " %.6f", fline.avTwoFXrecalc[X] );
-          UINT4 len1 = strlen ( recalcStr ) + strlen ( buf0 ) + 1;
-          if ( len1 > sizeof ( recalcStr ) ) {
-            XLALPrintError ("%s: assembled output string too long! (%d > %zu)\n", fn, len1, sizeof(recalcStr ));
-            break;	/* we can't really terminate with error in this function, but at least we avoid crashing */
-          }
-          strcat ( recalcStr, buf0 );
-        } /* for X < numDet */
+      print_single_detector_quantities_to_str ( recalcStr, sizeof(recalcStr), fline.avTwoFXrecalc, fline.numDetectors );
+
       if ( fline.twoFloudestSeg >= 0.0 ) /* this was initialised to -1.0 and is only >= 0.0 if actually recomputed in recalcToplistStats step */
       {
         snprintf ( buf0, sizeof(buf0), " %d %.6f", fline.loudestSeg, fline.twoFloudestSeg );
         strcat ( recalcStr, buf0 );
-        for ( UINT4 X = 0; X < fline.numDetectors ; X ++ )
-          {
-            snprintf ( buf0, sizeof(buf0), " %.6f", fline.twoFXloudestSeg[X] );
-            UINT4 len1 = strlen ( recalcStr ) + strlen ( buf0 ) + 1;
-            if ( len1 > sizeof ( recalcStr ) ) {
-              XLALPrintError ("%s: assembled output string too long! (%d > %zu)\n", fn, len1, sizeof(recalcStr ));
-              break;	/* we can't really terminate with error in this function, but at least we avoid crashing */
-            }
-            strcat ( recalcStr, buf0 );
-          } /* for X < numDet */
+        print_single_detector_quantities_to_str ( recalcStr, sizeof(recalcStr), fline.twoFXloudestSeg, fline.numDetectors );
       } /* if ( fline.twoFloudestSeg >= 0.0 ) */
-    } /* if avTwoFX */
+
+      if ( fline.log10BSGLtLrecalc > -LAL_REAL4_MAX*0.2 ) /* if --computeBSGL=FALSE, the log10BSGLtLrecalc field was initialised to -LAL_REAL4_MAX; if --computeBSGL=TRUE, it is at least -LAL_REAL4_MAX*0.1 */
+        {
+          snprintf ( buf0, sizeof(buf0), " %.6f", fline.log10BSGLtLrecalc );
+          strcat ( recalcStr, buf0 );
+        } /* if ( fline.log10BSGLtL > -LAL_REAL4_MAX*0.2 ) */
+
+    } /* if avTwoFrecalc */
 
   int len;
   if (fline.have_f3dot){
@@ -312,9 +356,9 @@ static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
 #ifdef EAH_BOINC /* for S5GC1HF Apps use exactly the precision used in the workunit generator
 		    (12g for Freq and F1dot) and skygrid file (7f for Alpha & Delta)
 		    as discussed with Holger & Reinhard 5.11.2010 */
-                     "%.16f %.7f %.7f %.12g %.12g %.12g %d %.6f%s%s\n",
+                     "%.16f %.7f %.7f %.12g %.12g %.12g %d %.6f%s%s%s%s%s\n",
 #else
-                     "%.16g %.13g %.13g %.13g %.13g %.13g %d %.6f%s%s\n",
+                     "%.16g %.13g %.13g %.13g %.13g %.13g %d %.6f%s%s%s%s%s\n",
 #endif
                      fline.Freq,
                      fline.Alpha,
@@ -325,6 +369,9 @@ static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
                      fline.nc,
                      fline.avTwoF,
                      BSGLstr,
+                     BSGLtLstr,
+                     BtSGLtLstr,
+                     maxTwoFstr,
                      recalcStr
                  );
   }
@@ -333,9 +380,9 @@ static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
 #ifdef EAH_BOINC /* for S5GC1HF Apps use exactly the precision used in the workunit generator
 		    (12g for Freq and F1dot) and skygrid file (7f for Alpha & Delta)
 		    as discussed with Holger & Reinhard 5.11.2010 */
-                     "%.16f %.7f %.7f %.12g %.12g %d %.6f%s%s\n",
+                     "%.16f %.7f %.7f %.12g %.12g %d %.6f%s%s%s%s%s\n",
 #else
-                     "%.16g %.13g %.13g %.13g %.13g %d %.6f%s%s\n",
+                     "%.16g %.13g %.13g %.13g %.13g %d %.6f%s%s%s%s%s\n",
 #endif
                      fline.Freq,
                      fline.Alpha,
@@ -345,6 +392,9 @@ static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
                      fline.nc,
                      fline.avTwoF,
                      BSGLstr,
+                     BSGLtLstr,
+                     BtSGLtLstr,
+                     maxTwoFstr,
                      recalcStr
                  );
 }
@@ -352,13 +402,56 @@ static int print_gctFstatline_to_str(GCTtopOutputEntry fline, char* buf, int buf
 
 } /* print_gctFstatline_to_str() */
 
+static int print_single_detector_quantities_to_str ( char *outstr, size_t outstrlen, const REAL4 *quantities, const UINT4 numDetectors ) {
+  const char *fn = __func__;
+
+  UINT4 len = strlen ( outstr );
+
+  char buf0[outstrlen];
+  for ( UINT4 X = 0; X < numDetectors ; X ++ ) {
+    snprintf ( buf0, sizeof(buf0), " %.6f", quantities[X] );
+    len = strlen ( outstr ) + strlen ( buf0 ) + 1;
+    if ( len > outstrlen ) {
+      XLALPrintError ("%s: assembled output string too long! (%d > %zu)\n", fn, len, outstrlen);
+      break;	/* we can't really terminate with error in this function, but at least we avoid crashing */
+    }
+    strcat ( outstr, buf0 );
+  } /* for X < numDet */
+
+  return len;
+
+} /* print_single_detector_quantities_to_str() */
+
+
+static int print_single_detector_intval_to_str ( char *outstr, size_t outstrlen, const INT4 *quantities, const UINT4 numDetectors ) {
+  const char *fn = __func__;
+
+  UINT4 len = strlen ( outstr );
+
+  char buf0[outstrlen];
+  for ( UINT4 X = 0; X < numDetectors ; X ++ ) {
+    snprintf ( buf0, sizeof(buf0), " %d", quantities[X] );
+    len = strlen ( outstr ) + strlen ( buf0 ) + 1;
+    if ( len > outstrlen ) {
+      XLALPrintError ("%s: assembled output string too long! (%d > %zu)\n", fn, len, outstrlen);
+      break;    /* we can't really terminate with error in this function, but at least we avoid crashing */
+    }
+    strcat ( outstr, buf0 );
+  } /* for X < numDet */
+
+  return len;
+
+} /* print_single_detector_quantities_to_str() */
+
+
+
 
 
 /* writes an GCTtopOutputEntry line to an open filepointer.
    Returns the number of chars written, -1 if in error
    Updates checksum if given */
 static int write_gctFstat_toplist_item_to_fp(GCTtopOutputEntry fline, FILE*fp, UINT4*checksum) {
-  char linebuf[256];
+  char linebuf[512];
   UINT4 i;
 
   UINT4 length = print_gctFstatline_to_str(fline, linebuf, sizeof(linebuf)-1);
@@ -410,8 +503,8 @@ int write_gctFstat_toplist_to_fp(toplist_t*tl, FILE*fp, UINT4*checksum) {
     *checksum = 0;
   for(i=0;i<tl->elems;i++)
     if ((r = write_gctFstat_toplist_item_to_fp(*((GCTtopOutputEntry*)(void*)(tl->heap[i])), fp, checksum)) < 0) {
-      LogPrintf (LOG_CRITICAL, "Failed to write toplistitem to output fp: %d: %s\n",
-		 errno,strerror(errno));
+      LogPrintf (LOG_CRITICAL, "Failed to write toplistitem to output fp: %d: %s %" LAL_UINT8_FORMAT "\n",
+		 errno,strerror(errno),i);
 #ifdef _MSC_VER
       LogPrintf (LOG_CRITICAL, "Windows system call returned: %d\n", _doserrno);
 #endif
@@ -501,8 +594,12 @@ static int _atomic_write_gctFstat_toplist_to_file(toplist_t *l, const char *file
         sortstat = "nc";
       else if ( l->smaller == gctBSGL_smaller )
         sortstat = "BSGL";
+      else if ( l->smaller == gctBSGLtL_smaller )
+        sortstat = "BSGLtL";
+      else if ( l->smaller == gctBtSGLtL_smaller )
+        sortstat = "BtSGLtL";
       else {
-        LogPrintf (LOG_CRITICAL, "Failed to write toplist sorting line, toplist is sorted by unknowns statistic.\n");
+        LogPrintf (LOG_CRITICAL, "Failed to write toplist sorting line, toplist is sorted by unknown statistic.\n");
         length = -1;
       }
       if (length >= 0) {
@@ -573,7 +670,7 @@ static int _atomic_write_gctFstat_toplist_to_file(toplist_t *l, const char *file
 /* New easier checkpointing - simply dump the whole toplist (plus a counter and
    a checksum) into a binary file.
    The heap structure array is hard to dump because it's based on pointers, so it
-   is restored after reding the data back in by sorting the list once.
+   is restored after reading the data back in by sorting the list once.
 */
 
 /** log an I/O error, i.e. source code line no., ferror, errno and strerror, and doserrno on Windows, too */
@@ -596,7 +693,7 @@ static int _atomic_write_gctFstat_toplist_to_file(toplist_t *l, const char *file
 #endif
 
 /* dumps toplist to a temporary file, then renames the file to filename */
-int write_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4 counter, BOOLEAN do_sync) {
+int write_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, toplist_t*t3, UINT4 counter, BOOLEAN do_sync) {
 #define TMP_EXT ".tmp"
   char*tmpfilename;
   FILE*fp;
@@ -706,6 +803,50 @@ int write_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4
     }
   } /* if t2 */
 
+  /* FIXME: this is getting silly, put this into a function and call it for the 
+     different toplists */
+
+  if (t3) {
+    /* write number of elements */
+    len = fwrite(&(t3->elems), sizeof(t3->elems), 1, fp);
+    if(len != 1) {
+      LOGIOERROR("Couldn't write elems to", tmpfilename);
+      LogPrintf(LOG_CRITICAL,"fwrite() returned %d, length was %d\n",len,1);
+      if(fclose(fp))
+        LOGIOERROR("In addition: couldn't close", tmpfilename);
+      LALFree(tmpfilename);
+      return(-1);
+    }
+
+    /* write data */
+    len = fwrite(t3->data, t3->size, t3->elems, fp);
+    if(len != t3->elems) {
+      LOGIOERROR("Couldn't write data to", tmpfilename);
+      LogPrintf(LOG_CRITICAL,"fwrite() returned %d, length was %zu\n", len, t3->elems);
+      if(fclose(fp))
+        LOGIOERROR("In addition: couldn't close", tmpfilename);
+      LALFree(tmpfilename);
+      return(-1);
+    }
+
+    /* dump heap order */
+    for(UINT4 i = 0; i < t3->elems; i++) {
+      UINT4 idx = (t3->heap[i] - t3->data) / t3->size;
+      len = fwrite(&idx, sizeof(idx), 1, fp);
+      if(len != 1) {
+        LOGIOERROR("Couldn't write idx to", tmpfilename);
+        LogPrintf(LOG_CRITICAL,"fwrite() returned %d, length was %d\n",len,1);
+        if(fclose(fp))
+          LOGIOERROR("In addition: couldn't close", tmpfilename);
+        LALFree(tmpfilename);
+        return(-1);
+      }
+      for(len = 0; len < sizeof(idx); len++)
+        checksum += *(((char*)&idx) + len);
+    }
+  } /* if t3 */
+
+
   /* write counter */
   len = fwrite(&counter, sizeof(counter), 1, fp);
   if(len != 1) {
@@ -728,6 +869,14 @@ int write_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4
     for(len = 0; len < (t2->elems * t2->size); len++)
       checksum += *(((char*)t2->data) + len);
   }
+
+  if (t3) {
+    for(len = 0; len < sizeof(t3->elems); len++)
+      checksum += *(((char*)&(t3->elems)) + len);
+    for(len = 0; len < (t3->elems * t3->size); len++)
+      checksum += *(((char*)t3->data) + len);
+  }
+
   for(len = 0; len < sizeof(counter); len++)
     checksum += *(((char*)&counter) + len);
 
@@ -774,7 +923,7 @@ int write_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4
 } /* write_gct_checkpoint() */
 
 
-int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4*counter) {
+int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, toplist_t*t3, UINT4*counter) {
   FILE*fp;
   UINT4 len;
   UINT4 checksum, indexsum = 0;
@@ -900,6 +1049,57 @@ int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4*c
     }
   } /* if (t2) */
 
+  if (t3) {
+    /* read number of elements */
+    len = fread(&(t3->elems), sizeof(t3->elems), 1, fp);
+    if(len != 1) {
+      LOGIOERROR("Couldn't read elems from", filename);
+      LogPrintf(LOG_CRITICAL,"fread() returned %d, length was %d\n", len, 1);
+      if(fclose(fp))
+        LOGIOERROR("In addition: couldn't close", filename);
+      return(-1);
+    }
+    /* sanity check */
+    if (t3->elems > t3->length) {
+      LogPrintf(LOG_CRITICAL,
+                "Number of elements read larger than length of toplist: %zu > %zu\n",
+                t3->elems, t3->length);
+      if(fclose(fp))
+        LOGIOERROR("In addition: couldn't close", filename);
+      return(-2);
+    }
+
+    /* read data */
+    len = fread(t3->data, t3->size, t3->elems, fp);
+    if(len != t3->elems) {
+      LOGIOERROR("Couldn't read data from", filename);
+      LogPrintf(LOG_CRITICAL,"fread() returned %d, length was %zu\n", len, t3->elems);
+      if(fclose(fp))
+        LOGIOERROR("In addition: couldn't close", filename);
+      clear_toplist(tl);
+      clear_toplist(t2);
+      clear_toplist(t3);
+      return(-1);
+    }
+
+    /* read heap order */
+    for(UINT4 i = 0; i < t3->elems; i++) {
+      UINT4 idx;
+      len = fread(&idx, sizeof(idx), 1, fp);
+      if(len != 1) {
+        LOGIOERROR("Couldn't read idx from", filename);
+        LogPrintf(LOG_CRITICAL,"fread() returned %d, length was %d\n",len,1);
+        if(fclose(fp))
+          LOGIOERROR("In addition: couldn't close", filename);
+        return(-1);
+      }
+      t3->heap[i] = (char*)(t3->data + idx * t3->size);
+      for(len = 0; len < sizeof(idx); len++)
+        indexsum += *(((char*)&idx) + len);
+    }
+  } /* if (t3) */
+
+
   /* read counter */
   len = fread(counter, sizeof(*counter), 1, fp);
   if(len != 1) {
@@ -909,6 +1109,7 @@ int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4*c
       LOGIOERROR("In addition: couldn't close", filename);
     clear_toplist(tl);
     if (t2) clear_toplist(t2);
+    if (t3) clear_toplist(t3);
     return(-1);
   }
 
@@ -920,6 +1121,8 @@ int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4*c
     if(fclose(fp))
       LOGIOERROR("In addition: couldn't close", filename);
     if (t2) clear_toplist(t2);
+    if (t3) clear_toplist(t3);
+
     clear_toplist(tl);
     return(-1);
   }
@@ -929,6 +1132,8 @@ int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4*c
     LOGIOERROR("Couldn't close", filename);
     clear_toplist(tl);
     if (t2) clear_toplist(t2);
+    if (t3) clear_toplist(t3);
+
     return(-1);
   }
 
@@ -944,12 +1149,20 @@ int read_gct_checkpoint(const char*filename, toplist_t*tl, toplist_t*t2, UINT4*c
     for(len = 0; len < (t2->elems * t2->size); len++)
       checksum -= *(((char*)t2->data) + len);
   }
+  if (t3) {
+    for(len = 0; len < sizeof(t3->elems); len++)
+      checksum -= *(((char*)&(t3->elems)) + len);
+    for(len = 0; len < (t3->elems * t3->size); len++)
+      checksum -= *(((char*)t3->data) + len);
+  }
   for(len = 0; len < sizeof(*counter); len++)
     checksum -= *(((char*)counter) + len);
   if(checksum) {
     LogPrintf(LOG_CRITICAL,"Checksum error: %d\n", checksum);
     clear_toplist(tl);
     if (t2) clear_toplist(t2);
+    if (t3) clear_toplist(t3);
+
     return(-2);
   }
 
