@@ -87,6 +87,7 @@ gct_dF2dot=0
 gct_nCands=10
 
 sqrtSh=1
+assumeSqrtSh=1
 
 ## --------- Generate fake data set time stamps -------------
 echo "----------------------------------------------------------------------"
@@ -116,14 +117,15 @@ iSeg=1
 while [ $iSeg -le $Nsegments ]; do
     t0=$tmpTime
     t1=$(($t0 + $Tsegment))
-    TspanHours=`echo $Tsegment | awk '{printf "%.7f", $1 / 3600.0 }'`
-        ## first and last segment will be single-IFO only
+
     if [ $iSeg -eq 1 -o $iSeg -eq $Nsegments ]; then
+        ## first and last segment will be single-IFO only
         NSFT=`echo $Tsegment $Tsft |  awk '{print int(1.0 * $1 / $2 + 0.5) }'`
-    else	## while all other segments are 2-IFO
+    else
+	## while all other segments are 2-IFO
         NSFT=`echo $Tsegment $Tsft |  awk '{print int(2.0 * $1 / $2 + 0.5) }'`
     fi
-    echo "$t0 $t1 $TspanHours $NSFT" >> $segFile
+    echo "$t0 $t1 $NSFT" >> $segFile
 
     segs[$iSeg]=$tmpTime # save seg's beginning for later use
     echo "Segment: $iSeg of $Nsegments	GPS start time: ${segs[$iSeg]}"
@@ -146,7 +148,7 @@ done
 
 echo
 echo "----------------------------------------------------------------------"
-echo " STEP 1: Generate Fake Signal"
+echo " STEP 1: Generate Fake Signal with MFDv5"
 echo "----------------------------------------------------------------------"
 echo
 
@@ -192,7 +194,8 @@ if [ ! -r "$outfile_cfs" ]; then
     tmpfile_cfs="${testDir}/__tmp_CFS.dat";
     cfs_CL_common=" --Alpha=$Alpha --Delta=$Delta --Freq=$Freq --f1dot=$f1dot --f2dot=$f2dot --outputLoudest=$tmpfile_cfs --refTime=$refTime --Dterms=$Dterms --RngMedWindow=$RngMedWindow --outputSingleFstats"
     if [ "$sqrtSh" = "0" ]; then
-        cfs_CL_common="$cfs_CL_common --SignalOnly";
+        # assume sqrtS=${assumeSqrtSh} in all detectors, regardless of how many detectors are in segment
+        cfs_CL_common="$cfs_CL_common --assumeSqrtSX=${assumeSqrtSh}";
     fi
 
     TwoFsum=0
@@ -254,14 +257,15 @@ echo "==>   Average <2F_multi>=$TwoFAvg, <2F_H1>=$TwoFAvg_H1, <2F_L1>=$TwoFAvg_L
 
 gct_CL_common="--gridType1=3 --nCand1=$gct_nCands --skyRegion='allsky' --Freq=$Freq --DataFiles='$SFTfiles' --skyGridFile='$skygridfile' --printCand1 --semiCohToplist --df1dot=$gct_dF1dot --f1dot=$f1dot --f1dotBand=$gct_F1dotBand  --df2dot=$gct_dF2dot --f2dot=$f2dot --f2dotBand=$gct_F2dotBand --dFreq=$gct_dFreq --FreqBand=$gct_FreqBand --refTime=$refTime --segmentList=$segFile --Dterms=$Dterms --blocksRngMed=$RngMedWindow"
 if [ "$sqrtSh" = "0" ]; then
-    gct_CL_common="$gct_CL_common --SignalOnly";
+    # assume sqrtS=${assumeSqrtSh} in both H1 and L1 detectors
+    gct_CL_common="$gct_CL_common --assumeSqrtSX=${assumeSqrtSh},${assumeSqrtSh}";
 fi
 
 BSGL_flags="--computeBSGL --Fstar0=10 --oLGX='0.5,0.5' --recalcToplistStats"
 
 echo
 echo "----------------------------------------------------------------------------------------------------"
-echo " STEP 3: run HierarchSearchGCT using Resampling (perfect match) and segment-list file and --recalcToplistStats"
+echo " STEP 3: run HierarchSearchGCT using Resampling and default 2F toplist"
 echo "----------------------------------------------------------------------------------------------------"
 echo
 
@@ -291,7 +295,7 @@ resGCT_RSr_L1=$(echo $topline  | awk '{print $14}')
 
 echo
 echo "----------------------------------------------------------------------------------------------------"
-echo " STEP 4: run HierarchSearchGCT using LALDemod (perfect match) and --tStack and --nStacksMax and --recalcToplistStats"
+echo " STEP 4: run HierarchSearchGCT using LALDemod and default 2F toplist"
 echo "----------------------------------------------------------------------------------------------------"
 echo
 
@@ -323,7 +327,7 @@ resGCT_DMr_L1=$(echo $topline  | awk '{print $14}')
 
 echo
 echo "----------------------------------------------------------------------------------------------------"
-echo " STEP 5: run HierarchSearchGCT using LALDemod (perfect match) and --tStack and --nStacksMax and --computeBSGL"
+echo " STEP 5: run HierarchSearchGCT using LALDemod and BSGL toplist"
 echo "----------------------------------------------------------------------------------------------------"
 echo
 
@@ -352,7 +356,7 @@ freqGCT_DM_BSGL=$(echo $topline | awk '{print $1}')
 
 echo
 echo "----------------------------------------------------------------------------------------------------"
-echo " STEP 6: run HierarchSearchGCT using LALDemod (perfect match) with 'dual' toplist: 1st=F, 2nd=BSGL"
+echo " STEP 6: run HierarchSearchGCT using LALDemod and dual toplist: 1st=F, 2nd=BSGL"
 echo "----------------------------------------------------------------------------------------------------"
 echo
 
@@ -382,7 +386,8 @@ fi
 
 echo
 echo "----------------------------------------------------------------------------------------------------"
-echo " STEP 7: run HierarchSearchGCT using Resampling (perfect match), triple toplist and recalc "
+echo " STEP 7: run HierarchSearchGCT using Resampling and triple toplist (BSGL, BSGLtL and BtSGLtL), "
+echo "         compared with separate runs for each of these 3 toplist rankings"
 echo "----------------------------------------------------------------------------------------------------"
 echo
 
