@@ -30,7 +30,6 @@ import sys
 import ast
 import numpy as np
 import re
-import urllib2
 import copy
 import os
 import fnmatch
@@ -172,59 +171,19 @@ function toggle(id) {{
 """
 
 
-def get_atnf_info(psr):
-  """
-  Get the pulsar (psr) distance (DIST in kpc), proper motion corrected period derivative (P1_I) and any association
-  (ASSOC e.g. GC) from the ATNF catalogue.
-  """
-
-  psrname = re.sub('\+', '%2B', psr) # switch '+' for unicode character
-
-  atnfversion = '1.54' # the latest ATNF version
-  atnfurl = 'http://www.atnf.csiro.au/people/pulsar/psrcat/proc_form.php?version=' + atnfversion
-  atnfurl += '&Dist=Dist&Assoc=Assoc&P1_i=P1_i' # set parameters to get
-  atnfurl += '&startUserDefined=true&c1_val=&c2_val=&c3_val=&c4_val=&sort_attr=jname&sort_order=asc&condition=&pulsar_names=' + psrname
-  atnfurl += '&ephemeris=selected&submit_ephemeris=Get+Ephemeris&coords_unit=raj%2Fdecj&radius=&coords_1=&coords_2='
-  atnfurl += '&style=Long+with+last+digit+error&no_value=*&fsize=3&x_axis=&x_scale=linear&y_axis=&y_scale=linear&state=query'
-
-  try:
-    urldat = urllib2.urlopen(atnfurl).read() # read ATNF url
-    predat = re.search(r'<pre[^>]*>([^<]+)</pre>', urldat) # to extract data within pre environment (without using BeautifulSoup) see e.g. http://stackoverflow.com/a/3369000/1862861 and http://stackoverflow.com/a/20046030/1862861
-    pdat = predat.group(1).strip().split('\n') # remove preceeding and trailing new lines and split lines
-  except:
-    print("Warning... could not get information from ATNF pulsar catalogue.")
-    return None
-
-  # check whether information could be found and get distance, age and association from data
-  dist = None
-  p1_I = None
-  assoc = None
-  for line in pdat:
-    if 'WARNING' in line or 'not in catalogue' in line:
-      return None
-    vals = line.split()
-    if 'DIST' in vals[0]:
-      dist = float(vals[1])
-    if 'P1_I' in vals[0]:
-      age = float(vals[1])
-    if 'ASSOC' in vals[0]:
-      assoc = vals[1]
-
-  return (dist, p1_I, assoc)
-
-
-def set_spin_down(p1_I, assoc, f0, f1):
+def set_spin_down(p1_I, assoc, f0, f1, n=5.):
   """
   Set the spin-down of the source based on the intrinsic period derivative (p1_I) corrected for any proper motion/
   globular cluster acceleration if available, or if not give AND the pulsar is in a globular cluster base the
-  spin-down on assuming an age of 10^9 years. Otherwise just return the unadjusted spin-down.
+  spin-down on assuming an age of 10^9 years (defaulting to the source being a gravitar, with n=5).
+  Otherwise just return the unadjusted spin-down.
   """
 
   if p1_I != None and p1_I > 0.:
     return -p1_I*f0**2 # convert period derivative into frequency derivative
   elif assoc != None:
     if 'GC' in assoc: # check if a globular cluster pulsar
-      return -f0/(2. * 1.e9 * 365.25 * 86400.)
+      return -f0/((n-1.) * 1.e9 * 365.25 * 86400.)
     else:
       return f1
   else:
@@ -442,7 +401,7 @@ class posteriors:
   """
   Get sample posteriors and created a set of functions for outputting tables, plots and posterior statistics
   """
-  def __init__(self, postfiles, outputdir, harmonics=[2], modeltype='waveform', biaxial=False, usegwphase=False, parfile=None, priorfile=None, subtracttruths=False, showcontours=False):
+  def __init__(self, postfiles, outputdir, ifos=None, harmonics=[2], modeltype='waveform', biaxial=False, usegwphase=False, parfile=None, priorfile=None, subtracttruths=False, showcontours=False):
     """
     Initialise with a dictionary keyed in detector names containing paths to the equivalent posterior samples
     file for that detector.
@@ -452,7 +411,19 @@ class posteriors:
       print("Error... output path '%s' for data plots does not exist" % self._outputdir, file=sys.stderr)
       sys.exit(1)
 
-    self._ifos = list(postfiles.keys())    # get list of detectors
+    if ifos is None: # get list of detectors from postfiles dictionary
+      self._ifos = list(postfiles.keys())    # get list of detectors
+    else:
+      if isinstance(ifos, list):
+        self._ifos = ifos
+      else:
+        self._ifos = [ifos]
+      # check ifos are in postfiles dictionary
+      for ifo in self._ifos:
+        if ifo not in postfiles:
+          print("Error... posterior files for detector '%s' not given" % ifo, file=sys.stderr)
+          sys.exit(1)
+
     self._postfiles = postfiles
     self._posteriors = {}                  # dictionary of posterior objects
     self._posterior_stats = {}             # dictionary if posteriors statistics
@@ -522,7 +493,7 @@ class posteriors:
           sys.exit(1)
 
         if priorlinevals[1] in ['uniform', 'fermidirac', 'gaussian', 'loguniform']:
-          if len(prirolinevals) != 4:
+          if len(priorlinevals) != 4:
             print("Error... there must be four values on each line of the prior file '%s'." % self._priorfile, file=sys.stderr)
             sys.exit(1)
           ranges = np.array([float(priorlinevals[2]), float(priorlinevals[3])]) # set ranges
@@ -928,7 +899,7 @@ class posteriors:
         x = self._posteriors[ifo][parameters[0]].samples
         for param in parameters[1:]:
           x = np.hstack((x, self._posteriors[ifo][param].samples))
-        showcontours = True
+        showcontours = self._showcontours
         contourops = {'colors': 'dark'+coldict[plotifos[k+1]]}
         if whichtruth == plotifos[k+1]:
           truthops = {'color': 'black', 'markeredgewidth': 2}
@@ -1145,7 +1116,7 @@ class posteriors:
           contourlimits.append(limits[p])
           figlimits.append(limits[p])
       if notpresent: break
-      # contourlimits = None # temporary for testing
+
       pf = self.create_joint_posterior_plot(parampairs, figformats=['png'], ratio=2, figlimits=figlimits, contourlimits=contourlimits, jointsamples=False)
       if allparams:
         tagclass = 'jointplot'
@@ -1836,13 +1807,32 @@ pdf_output = False      # a boolean stating whether to also output pdf versions
   dist = p1_I = assoc = sdlim = f1sd = None
   atnfurl = None
   if not injection:
-    pinfo = get_atnf_info(pname)
-    if pinfo != None:
-      dist, p1_I, assoc = pinfo # unpack values
-      atnfversion = '1.54'
-      atnfurl = 'http://www.atnf.csiro.au/people/pulsar/psrcat/proc_form.php?version=' + atnfversion
-      atnfurl += '&startUserDefined=true&pulsar_names=' + re.sub('\+', '%2B', pname)
-      atnfurl += '&ephemeris=long&submit_ephemeris=Get+Ephemeris&state=query'
+    # set ATNF URL where pulsar can be found
+    atnfurl = 'http://www.atnf.csiro.au/people/pulsar/psrcat/proc_form.php?version=' + ATNF_VERSION
+    atnfurl += '&startUserDefined=true&pulsar_names=' + re.sub('\+', '%2B', pname)
+    atnfurl += '&ephemeris=long&submit_ephemeris=Get+Ephemeris&state=query'
+
+    # try getting information already parsed from ATNF catalogue by lalapps_knope pipeline setup
+    jsonfile = os.path.join(outdir, pname+'.json')
+    tryatnf = True
+    if os.path.isfile(jsonfile):
+      try:
+        fp = open(jsonfile, 'r')
+        info = json.load(fp)
+        fp.close()
+
+        # extract distance, intrinsic period derivative, pulsar association and required URL
+        dist = info['Pulsar data']['DIST']
+        p1_I = info['Pulsar data']['P1_I']
+        assoc = info['Pulsar data']['ASSOC']
+        tryatnf = False
+      except:
+        print("Warning... could not read in JSON file '%s'." % jsonfile, file=sys.stderr)
+
+    if tryatnf: # try getting ATNF info now
+      pinfo = get_atnf_info(pname)
+      if pinfo is not None:
+        dist, p1_I, assoc = pinfo # unpack values
 
     # if distance is in the par file use that instead
     if par['DIST']:
@@ -1852,7 +1842,7 @@ pdf_output = False      # a boolean stating whether to also output pdf versions
     f1sd = set_spin_down(p1_I, assoc, f0, f1)
 
     # get spin-down limit
-    if f1sd != None and dist != None:
+    if f1sd is not None and dist is not None:
       sdlim = spin_down_limit(f0, f1sd, dist)
 
   # check whether to only include results from a joint (multi-detector) analysis
@@ -2025,7 +2015,7 @@ pdf_output = False      # a boolean stating whether to also output pdf versions
   htmlinput['pulsartable'] = psrtable
 
   # get posterior class (containing samples, sample plots and posterior plots)
-  postinfo = posteriors(postfiles, outdir, harmonics=harmonics, modeltype=modeltype,
+  postinfo = posteriors(postfiles, outdir, ifos=ifos, harmonics=harmonics, modeltype=modeltype,
                         biaxial=biaxial, parfile=parfile, usegwphase=usegwphase,
                         subtracttruths=subtracttruths, priorfile=priorfile,
                         showcontours=showcontours)
