@@ -46,7 +46,7 @@
 #include <lal/AVFactories.h>
 #include <lal/SkyCoordinates.h>
 #include <lal/ComputeFstat.h>
-#include <lal/PulsarTimes.h>
+#include <lal/GetEarthTimes.h>
 #include <lal/SFTutils.h>
 #include <lal/LALString.h>
 
@@ -54,7 +54,6 @@
 #include <lal/LogPrintf.h>
 #include <lal/StringVector.h>
 
-#include <lal/FlatPulsarMetric.h>
 #include <lal/UniversalDopplerMetric.h>
 #include <lal/MetricUtils.h>
 
