@@ -1105,9 +1105,9 @@ int XLALReadSFTs(SFTVector **sftvec,        /**< [out] the input SFT data */
   freqmax = freqmin + freqband;
 
   /* check CRC sums of SFTs */
-  /* LAL_CALL ( LALCheckSFTCatalog ( &status, &sft_check_result, catalog ), &status );
+  /* XLAL_CHECK_MAIN ( XLALCheckCRCSFTCatalog (&sft_check_result, catalog ) == XLAL_SUCCESS, XLAL_EFUNC );
   if (sft_check_result) {
-    LogPrintf(LOG_CRITICAL,"%s : LALCheckSFTCatalogSFT() validity check failed with error = %d\n", sft_check_result);
+    LogPrintf(LOG_CRITICAL,"%s : XLALCheckCRCSFTCatalogSFT() validity check failed with error = %d\n", sft_check_result);
     return 1;
   }
   LogPrintf(LOG_DEBUG,"%s : checked the SFTs\n",__func__); */
@@ -1293,26 +1293,6 @@ int XLALComputeBinaryGridParams(GridParameters **binarygridparams,  /**< [out] t
 
 }
 
-/** Append the given SFTtype to the SFT-vector (no SFT-specific checks are done!) */
-int XLALAppendSFT2Vector (SFTVector *vect,		/**< destinatino SFTVector to append to */
-                          const SFTtype *sft            /**< the SFT to append */
-                          )
-{
-  UINT4 oldlen = vect->length;
-
-  if ( (vect->data = LALRealloc ( vect->data, (oldlen + 1)*sizeof( *vect->data ) )) == NULL ) {
-     LogPrintf(LOG_CRITICAL,"%s: Error, unable to allocate memory\n",__func__);
-     XLAL_ERROR(XLAL_EINVAL);
-  }
-  memset ( &(vect->data[oldlen]), 0, sizeof( vect->data[0] ) );
-  vect->length ++;
-
-  XLALCopySFT(&vect->data[oldlen], sft );
-
-  return XLAL_SUCCESS;
-
-} /* XLALAppendSFT2Vector() */
-
 /** Convert an input binary file into an SFTVector
  *
  *
